import { CheckIn } from 'models/chain/CheckIn'
import { NftHolder } from 'models/chain/NftHolder'
import { NftStake } from 'models/chain/NftStake'
import { getMonthBegin, getNDayAgo } from 'zutils/utils/date.util'

export const queryCheckInList = async (address: string, days: string | number | string[], limit: number = 0) => {
  let query: any = { from: address.toLowerCase() }
  if (!limit) {
    if (typeof days === 'number') {
      let begin = getNDayAgo(days, true)
      query.blockTime = { $gt: (begin.getTime() / 1000) | 0 }
    } else if (typeof days === 'string') {
      if (days === '1month') {
        let date = getMonthBegin(new Date())
        query.blockTime = { $gt: (date.getTime() / 1000) | 0 }
      } else {
        query.dateTag = days
      }
    } else if (Array.isArray(days)) {
      query.dateTag = { $in: days }
    }
  }
  let records
  if (limit) {
    records = await CheckIn.find(query).sort({ _id: -1 }).limit(limit)
  } else {
    records = await CheckIn.find(query).sort({ _id: -1 })
  }
  let result = []
  for (let record of records) {
    result.push(record.toJson())
  }
  return result
}

export const queryCheckInSeq = async (address: string) => {
  const record = await CheckIn.findOne({ from: address.toLowerCase() }).sort({ count: -1 })
  return record.toJson()
}

export const queryBurnNftList = async (address: string, user: string, chain: string) => {
  address = address.toLowerCase()
  user = user.toLowerCase()

  let records = await NftHolder.find({ address, chain, user, burn: true }).sort({ blockNumber: -1 })
  let result = []
  for (let record of records) {
    result.push({
      address: record.address,
      chain: record.chain,
      user: record.user,
      tokenId: record.tokenId,
    })
  }
  return result
}

export const checkHadGacha = async (user: string) => {
  const chain = process.env.CHAIN + ''
  const address = process.env.GACHA_CONTRACT
  const record = await NftHolder.findOne({ user, chain, address })
  return !!record
}

export const queryStakeList = async (userAddress: string) => {
  const chain = process.env.CHAIN + ''
  const address = process.env.BADGE_CONTRACT
  let records = await NftStake.find({ chain, nft: address, user: userAddress.toLowerCase() })
  return records
}
